==> indigitall_flutter_plugin-2.0.2.tar.gz: ios/Classes/utils/IndigitallInboxFParse.h <==
//
//  IndigitallInboxParse.h
//  indigitall_flutter_plugin
//
//  Created by indigitall on 18/1/23.
//
#import <Flutter/Flutter.h>
#import <Indigitall/Indigitall.h>

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface IndigitallInboxFParse : NSObject
+ (NSDictionary *) jsonFromMessagesCounter: (INInboxCounters *) inboxCounter;
+ (NSDictionary *) jsonFromInbox: (Inbox *) inbox newNotifications:(NSArray<INInboxNotification *> *)newNotifications callback: (NSString *)callback;
+ (NSArray<NSString *>*) jsonArrayFromInboxNotification: (NSArray<INInboxNotification *>* _Nullable) inboxNotifications;
+ (NSDictionary *) jsonFromCategory: (InboxCategory *) category;
+ (NSDictionary *) jsonFromPush: (INPush *) message;
+ (NSDictionary *) jsonFromPushAction: (INPushAction *) action;
+ (NSArray<NSDictionary *>*) jsonArrayFromPushButtons: (NSArray<INPushButton *>*) buttons;
+ (void) successWithInbox: (Inbox *)inbox newNotifications:(NSArray<INInboxNotification *> *)newNotifications  methodGetInbox:(BOOL)methodGetInbox result: (FlutterResult _Nonnull)result ;
+ (void) successWithInboxCounter: (INInboxCounters *)counters  result: (FlutterResult _Nonnull)result;
+ (void) successWithInboxNotification: (INInboxNotification *)inboxNotification callback: (NSString *)callback result: (FlutterResult _Nonnull)result;
+ (void) resultFromString: (NSString *)string withAction: (NSString *)action withResult: (FlutterResult _Nonnull) result;
+ (void) jsonFromError: (INError *)error withResult: (FlutterResult _Nonnull) result;
@end

NS_ASSUME_NONNULL_END

==> indigitall_flutter_plugin-2.5.1.tar.gz: ios/Classes/utils/IndigitallInboxFParse.h <==
//
//  IndigitallInboxParse.h
//  indigitall_flutter_plugin
//
//  Created by indigitall on 18/1/23.
//
#import <Flutter/Flutter.h>
#import <Indigitall/Indigitall.h>

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface IndigitallInboxFParse : NSObject
+ (NSDictionary *) jsonFromMessagesCounter: (INInboxCounters *) inboxCounter;
+ (NSDictionary *) jsonFromInbox: (INInbox *) inbox newNotifications:(NSArray<INInboxNotification *> *)newNotifications callback: (NSString *)callback;
+ (NSArray<NSString *>*) jsonArrayFromInboxNotification: (NSArray<INInboxNotification *>* _Nullable) inboxNotifications;
+ (NSDictionary *) jsonFromCategory: (INInboxCategory *) category;
+ (NSDictionary *) jsonFromPush: (INPush *) message;
+ (NSDictionary *) jsonFromPushAction: (INPushAction *) action;
+ (NSArray<NSDictionary *>*) jsonArrayFromPushButtons: (NSArray<INPushButton *>*) buttons;
+ (void) successWithInbox: (INInbox *)inbox newNotifications:(NSArray<INInboxNotification *> *)newNotifications  methodGetInbox:(BOOL)methodGetInbox result: (FlutterResult _Nonnull)result ;
+ (void) successWithInboxCounter: (INInboxCounters *)counters  result: (FlutterResult _Nonnull)result;
+ (void) successWithInboxNotification: (INInboxNotification *)inboxNotification callback: (NSString *)callback result: (FlutterResult _Nonnull)result;
+ (void) resultFromString: (NSString *)string withAction: (NSString *)action withResult: (FlutterResult _Nonnull) result;
+ (void) jsonFromError: (INError *)error withResult: (FlutterResult _Nonnull) result;
@end

NS_ASSUME_NONNULL_END
